changelog
=========

Version 0.2, 10 February 2010
*****************************

* Changed focus and aim of project
* Removed all previous custom admin work
* Incorporated CloudFilesStorage custom storage backend
* Added sphinx docs
* Converted setup to use distribute

Version 0.1, 28 July 2009
*************************

* Initial release
